
# Slot: related to




URI: [ks:related_to](https://w3id.org/linkml/tests/kitchen_sink/related_to)


## Domain and Range

None &#8594;  <sub>0..1</sub> [String](String.md)

## Parents


## Children

 *  [FamilialRelationship➞related to](FamilialRelationship_related_to.md)

## Used by

 * [Relationship](Relationship.md)
